wifi
----

WiFi tools that could possibly work on a nice day, if you are lucky.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

::

    # apt-get install ifscheme
    # pip install wifi
    # wifi --help
